Documentation
¶
Index ¶
- type Entry
- type Index
- type IndexEntry
- type MessageStore
- func (ms *MessageStore) Delete(topic string) error
- func (ms *MessageStore) PollForNextEntry(topic string, offset int64, pollDuration time.Duration) (*Entry, error)
- func (ms *MessageStore) ReadEntry(topic string, offset int64) (*Entry, error)
- func (ms *MessageStore) SaveEntry(topic string, entry Entry) (int64, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Index ¶
type Index struct {
// contains filtered or unexported fields
}
Index represents the index file
type IndexEntry ¶
IndexEntry represents an entry in the index
type MessageStore ¶
type MessageStore struct {
// contains filtered or unexported fields
}
MessageStore manages topics and stores topic entries in text files
func NewMessageStore ¶
func NewMessageStore() *MessageStore
NewMessageStore creates a new instance of MessageStore
func (*MessageStore) Delete ¶
func (ms *MessageStore) Delete(topic string) error
Delete will remove the specified topic
func (*MessageStore) PollForNextEntry ¶ added in v0.0.3
func (ms *MessageStore) PollForNextEntry(topic string, offset int64, pollDuration time.Duration) (*Entry, error)
PollForNextEntry reads an entry from the given offset+1 from the specified topic, after sleeping for the specified poll interval
Click to show internal directories.
Click to hide internal directories.